<?php

namespace Drupal\google_groups\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Google_Client;
use Google_Service_Directory;

/**
 *  Class for implementing Google groups authorization form.
 */
class GoogleGroupsAuthorizeForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'google_groups.authorize';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_groups_authorize';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config(static::SETTINGS);

    $form['google_groups_file_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Group File Path'),
      '#default_value' => $config->get('google_groups_file_path'),
      '#description' => $this->t('Please enter full URL from root of server.'),
      '#required' => TRUE,
    ];

    $form['google_groups_subject'] = [
      '#type' => 'email',
      '#title' => $this->t('Group Subject'),
      '#default_value' => $config->get('google_groups_subject'),
      '#description' => $this->t('Please enter the email address which have admin permission for group.'),
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $client = new Google_Client();
    $client->setAuthConfig(trim($form_state->getValue('google_groups_file_path')));
    $client->setSubject(trim($form_state->getValue('google_groups_subject')));
    $client->setScopes([
      Google_Service_Directory::ADMIN_DIRECTORY_USER,
      Google_Service_Directory::ADMIN_DIRECTORY_GROUP,
    ]);

    $config = $this->config(static::SETTINGS);
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('google_groups_file_path', trim($form_state->getValue('google_groups_file_path')))
      ->set('google_groups_subject', trim($form_state->getValue('google_groups_subject')))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
