<?php

namespace Drupal\google_groups\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger;

class GoogleGroupsForm extends EntityForm {

  /**
   * {@inheritdoc}
   *
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form = parent::form($form, $form_state);
    $google_groups = $this->entity;
    $form['group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Group Name'),
      '#default_value' => $google_groups->get('group_name'),
      '#required' => TRUE ,
      '#description' => t("Your Google Group's human readable name."),
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#machine_name' => [
        'exists' => [$this, 'exist'],
        'source' => [ 'group_name' ]
      ],
      '#default_value' => $google_groups->get('id'),
    ];

    $form['group_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Group Id'),
      '#default_value' => $google_groups->get('group_id'),
      '#required' => TRUE ,
      '#description' => $this->t("Enter full email address of group."),
    ];

    $form['register'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Registration Form'),
      '#description' => $this->t('Options for subscribing via the registration form.'),
    ];

    $form['register']['register'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow subscription during registration'),
      '#default_value' => $google_groups->get('register'),
      '#description' => $this->t('This will add a subscription checkbox to the registration form.'),
    ];

    $form['register']['default'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Checked by default'),
      '#default_value' => $google_groups->get('default'),
      '#description' => $this->t('If checked, the subscription checkbox on the registration form will be checked by default.'),
    ];

    $form['register']['forced'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Force default'),
      '#default_value' => $google_groups->get('forced'),
      '#description' => $this->t('If checked, the subscription checkbox on the registration form will be disabled. User will not be able to change it from its default setting. Useful to force user subscription.'),
    ];

    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $google_groups = $this->entity;
    $status = $google_groups->save();

    switch ($status) {
      case SAVED_NEW:
        $this->messenger()->addStatus($this->t('Created @group_name Google Group.' , [
          '@group_name' => $google_groups->get('group_name'),
        ]));
        break;

      default:
        $this->messenger()->addStatus($this->t('Saved the @group_name Google Groups .', [
          '@group_name' => $google_groups->get('group_name'),
        ]));
    }
    $form_state->setRedirectUrl($google_groups->toUrl('collection'));
  }

  /**
   * Helper function to check whether an GoogleGroup configuration entity exists.
   */
  public function exist($id) {

    $entity = \Drupal::entityTypeManager()->getStorage('google_groups')->getQuery()
      ->condition('id', $id)
      ->execute();
    return (bool) $entity;   
  }
}
