<?php

namespace Drupal\google_groups\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\google_groups\Form\GroupsBlockForm;

/**
 * Provides a block to subscribe.
 *
 * @Block(
 *   id = "google_groups_block",
 *   admin_label = @Translation("Google Groups Block") ,
 *   deriver = "Drupal\google_groups\Plugin\Derivative\GroupsBlock"
 * )
 */
class GoogleGroupsBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   * @param \Drupal\Core\Form\FormBuilderInterface $formBuilder
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $formBuilder) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $formBuilder; 
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $id = $this->getDerivativeId();
    $form = $this->formBuilder->getForm(GroupsBlockForm::class);
    $form['group_id']['#value'] = $id;
    return $form;
  }
  
  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   *
   * @return static
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder')
    );
  }
}
