<?php

namespace Drupal\google_groups\Services;

use Drupal\Core\Config\ConfigFactoryInterface;
use Google_Client;
use Google_Service_Directory;
use Google_Service_Directory_Member;

/**
 * Serivce to  communicate with google groups.
 */
class GoogleGroupsApiClientService {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Variable for storing Google Client Object.
   *
   * @var \Google_Client
   */
  protected $googleClient;

  /**
   * Variable for storing Google Client Service Object.
   *
   * @var \Google_Service_Directory
   */
  protected $service;

  /**
   * GoogleGroupsApiClientService constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A config factory for retrieving required config objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Initate the client with Googel Client object.
   */
  public function initiateClient() {
    $group_obj = $this->configFactory->getEditable('google_groups.authorize');
    $api_subject = $group_obj->get('google_groups_subject');
    $api_file_path = $group_obj->get('google_groups_file_path');

    $client = new Google_Client();
    $client->setAuthConfig($api_file_path);
    $client->setSubject($api_subject);
    $client->setScopes([
      Google_Service_Directory::ADMIN_DIRECTORY_USER,
      Google_Service_Directory::ADMIN_DIRECTORY_GROUP,
    ]);
    $this->googleClient = $client;
    $this->service = new Google_Service_Directory($this->googleClient);
  }

  /**
   * Check whether member exist or not.
   */
  public function validateClient() {
    if (empty($this->service)) {
      $this->initiateClient();
    }
  }

  /**
   * List all the members of google groups.
   */
  public function listMembers($group_email) {

    $this->validateClient();
    $results = $this->service->members->listMembers($group_email);
    return $results;
  }

  /**
   * Add member if not a google group member.
   */
  public function addMember($group_email, $user_email) {

    $this->validateClient();
    $user = new Google_Service_Directory_Member([
      'email' => $user_email,
      'kind' => 'admin#directory#member',
      'role' => 'MEMBER',
      'type' => 'USER',
    ]);

    $add_member = $this->service->members->insert($group_email, $user);
    return $add_member;
  }

  /**
   * Remove member from  google group.
   */
  public function removeMember($group_email, $user_email) {

    $this->validateClient();
    $remove_member = $this->service->members->delete($group_email, $user_email);
    return $remove_member;
  }

  /**
   * Check if the member subsribed is the google group member.
   */
  public function hasMember($group_email, $user_email) {

    $this->validateClient();
    $has_member = $this->service->members->hasMember($group_email, $user_email);
    return $has_member;
  }

}
